#
# spec file for package perl-File-Find-Object
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-Find-Object
Name:           perl-File-Find-Object
Version:        0.3.9
Release:        1.2
License:        Artistic-2.0
Summary:        An object oriented File::Find replacement
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::XSAccessor)
BuildRequires:  perl(File::TreeCreate)
BuildRequires:  perl(Module::Build) >= 0.28
BuildRequires:  perl(Test::File) >= 1.993
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(parent)
Requires:       perl(Class::XSAccessor)
Requires:       perl(parent)
%{perl_requires}

%description
File::Find::Object does the same job as File::Find but works like an object
and with an iterator. As File::Find is not object oriented, one cannot
perform multiple searches in the same application. The second problem of
File::Find is its file processing: after starting its main loop, one cannot
easily wait for another event and so get the next result.

With File::Find::Object you can get the next file by calling the next()
function, but setting a callback is still possible.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Thu Dec 12 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.3.9
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.9       2024-12-11
  - Avoid implicit symbol imports.
  - https://perl-begin.org/tutorials/bad-elements/#non_explicitly_imported_symbols
* Sun Jul 23 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.3.8
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.8       2023-07-22
  - Fix use_ok() call.
  - https://github.com/shlomif/perl-file-find-object/pull/3
  - Thanks to @haarg .
* Mon Jan  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.3.7
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.7       2023-01-01
  - Fix test failures on mswin
  - https://github.com/shlomif/perl-file-find-object/issues/2
  - thanks to @jddurand
* Thu Oct 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.3.6
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.6       2021-08-26
  - Extract https://metacpan.org/pod/File::TreeCreate .
* Tue Sep 14 2021 Dirk Stoecker <opensuse@dstoecker.de>
- refresh spec file
* Wed Jan 29 2020 <timueller+perl@suse.de>
- updated to 0.3.5
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  Revision history for File-Find-Object
  0.3.5       2020-01-28
  - Rebuild for order of 'NAME' and 'VERSION' sections in the generated
    POD documentation (see:
    https://metacpan.org/changes/distribution/Pod-Weaver-PluginBundle-SHLOMIF#L3
    ).
  - VERSION used to appear before NAME.
* Mon Aug 26 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.3.4
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.4   2019-08-25
  - Add *~ files to MANIFEST.SKIP.
  - https://github.com/shlomif/perl-file-find-object/issues/1
  -  Thanks to @perlpunk and SUSE.
* Sat Aug 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.3.3
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.3   2019-08-23
  - Now at https://github.com/shlomif/perl-file-find-object
  - tidyall .
* Mon Oct  8 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.3.2
  see /usr/share/doc/packages/perl-File-Find-Object/Changes
  0.3.2   2017-01-13
  - Made the version number consistent across the .pm files.
  - https://bitbucket.org/shlomif/perl-file-find-object/issues/1/wrong-version-number
  - Thanks to aer0 for the report.
  0.3.1   2017-01-09
  - Fixed an issue with tracking the depth of the inodes when detecting
    a symlink loop.
  - Detected by several cygwin reports.
  0.3.0   2016-09-11
  - Converted the build system to Dist-Zilla.
  - Part of the impetus was removing the warning about
    Test::TrailingSpace needed for the trailing whitespace tests
    (which in turn requires this modules) which was reported to us as a
    problem by someone (despite not being a real issue).
* Fri Apr 17 2015 coolo@suse.com
- initial package 0.2.13
